#!/bin/bash
if : ; then
# File:         shells.sh
# Name:         Kevin Crotty
# Date:         21 Mar 2019
# Desc:         Display common shelles and relevant commands
# Usage:        ./shells.sh and source shells

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

echo -e "${BPurple}***NOTE: RUN and SOURCE this script!!!!!***${NC}"
echo -e "\n${BPurple}Commands relating to shells in Linux\n${NC}"

echo -e "${BGreen}# Display file with a list of available shells \n${BRed}cat /etc/shells ${NC}"
cat /etc/shells | head -n5

echo -e "\n${BGreen}# Define the default shell in /etc/passwd\n${BRed}cat /etc/passwd${NC}"
echo -e "root:x:0:0:root:/root${BCyan}:/bin/bash${NC}"
echo -e "sync:x:4:65534:sync:/bin${BCyan}:/bin/sync${NC}"
echo -e "gdm:x:121:125:Gnome Display Manager:/var/lib/gdm3${BCyan}:/bin/false${NC}"
echo -e "crotty:x:1001:1001::/home/crotty${BCyan}:/bin/bash${NC}"

echo -e "\n${BGreen}#  The full pathname to the shell is kept in this environment variable."
echo -e "#+ If it is not set when the shell starts, bash assigns to it the full pathname of the current user's login shell."
echo -e "${BRed}echo \$SHELL ${NC}"
echo $SHELL

echo -e "\n${BGreen}# Expands to the full filename used to invoke this instance of bash\n${BRed}echo \$BASH ${NC}"
echo $BASH

echo -e "\n${BPurple}# Some Special Parameters"

colorComment "# Expands to the name of the shell or shell script."
echo -e "${BRed}echo \$0${NC}"
echo $0

colorComment "# Expands to the process ID of the shell."
echo -e "${BRed}echo \$\$${NC}"
echo $$

colorComment "# Expands to the exit status of the most recently executed foreground pipeline."
echo -e "${BRed}echo \$?${NC}"
echo $?

colorComment "# Expands to the current option flags as specified upon invocation."
echo -e "${BGreen}#+ h = Hash Table is enabled" 
echo -e "${BGreen}#+ i = Shell is interactive"
echo -e "${BGreen}#+ m = Job Control is enabled"
echo -e "${BGreen}#+ B = Brace Expansion is enabled"
echo -e "${BGreen}#+ H = History Expansion is enabled"
echo -e "${BGreen}#+ s = Shell is reading from STDIN"
echo -e "${BGreen}#+ Or use: set --help"
echo -e "${BRed}echo \$-${NC}"
echo $-


echo -e "\n\n\n\n"
