#!/bin/bash
if : ; then
# File:         expansion.sh
# Name:         Kevin Crotty
# Date:         23 Mar 2019
# Desc:         Bash Expansion Demo's
# Usage:        ./expansion.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

function quotes_demo
{
    echo -e "${BGreen}# Create a file from a script"
    echo -e "${BRed}cat > quotes.txt << EOF ${NC}"
    echo -e "${BRed}This is ${NC}"
    echo -e "${BRed}a ${NC}"
    echo -e "${BRed}line of text ${NC}"
    echo -e "${BRed}with spaces ${NC}"
    echo -e "${BRed}EOF ${NC}"

cat > quotes.txt << EOF
This is
a
line of text
with spaces
EOF

    echo -e "\n${BGreen}# Set the 'file' variable to the new quotes.txt file"
    echo -e "${BRed}file=quotes.txt ${NC}"
    file=quotes.txt

    echo -e "\n${BGreen}# Show the differences with quoting"
    echo -e "${BRed}echo \$(cat \$file)${NC}"
    echo -e $(cat $file)"\n"
    echo -e "${BRed}echo \"\$(cat \$file)\"${NC}"
    echo -e "$(cat $file)\n"
    echo -e "${BRed}echo '\$(cat \$file)' ${NC}"
    echo -e '$(cat $file)'

    #echo -e "${BRed}  ${NC}"
    rm *.txt
    echo && echo
}

function braces_demo
{
    echo -e "${BGreen}# Single Expansion"
    echo -e "${BRed}echo {a..e}${NC}"
    echo {a..e}

    echo -e "\n${BGreen}# Multiple Expansions"
    echo -e "${BRed}touch file{1..3}{a..b}.txt${NC}"
    touch file{1..3}{a..b}.txt
    echo -e "${BRed}ls -l *.txt${NC}"
    ls -l *.txt

    echo -e "\n${BGreen}# for loop examples"
    echo -e "${BRed}for i in {1..4} ; do echo -n \$i ; done${NC}"
    for i in {1..4} ; do echo -n $i ; done

    echo -e "\n\n${BRed}for i in {1,nine,\"two words\"} ; do echo \$i ; done${NC}"
    for i in {1,nine,"two words"} ; do echo  $i ; done

    rm  *.txt
    echo && echo
}

function variables_demo
{
    echo -e "\n${BGreen}# Environment Variables"
    echo -e "${BRed}echo \"SHELL = \$SHELL, HOME = \$HOME, VISUAL = \$VISUAL\" ${NC}"
    echo "SHELL = $SHELL, HOME = $HOME, VISUAL = $VISUAL"

    echo -e "\n${BGreen}# User Defined Local Variables"
    echo -e "${BRed}var1='This is' ; var2='a sentence' ${NC}"
    var1='This is' ; var2='a sentence'
    echo -e "${BRed}echo \$var1 \$var2 ${NC}"
    echo $var1 $var2
    echo -e "\n${BRed}echo \$var1 \$var2stuff ${NC}"
    echo $var1 $var2stuff
    echo -e "\n${BRed}echo \$var1 \${var2}stuff ${NC}"
    echo $var1 ${var2}stuff

    echo && echo
}

function math_demo
{
    echo -e "\n${BGreen}# Arithmetic Expansion"
    echo -e "${BRed}a=5; b=10 ${NC}"
    a=5; b=10
    echo -e "${BRed}c=\$((a + b + 5)) ; echo \$c ${NC}"
    c=$((a + b + 5)) ; echo $c

    echo -e "\n${BGreen}# Post and Pre Increment"

    echo -e "${BRed}d=5; echo \$((d++)) \$d${NC}"
    d=5; echo $((d++)) $d
    echo -e "${BRed}d=5; echo \$((++d)) \$d${NC}"
    d=5; echo $((++d)) $d

    echo && echo
}

mainMenu () {

clear

while :
do
    #clear

    echo
    echo "Choose from the following options:"
    echo "----------------------------------"
    echo "  [1] Quotes Demo"
    echo "  [2] Brace Expansion Demo"
    echo "  [3] Variable Expansion Demo"
    echo "  [4] Arithmetic Expansion Demo"
    echo
    echo "  [X] to Exit : [C] to Clear the Screen" && echo

    read -p "Choice: " choice
    echo

    case "$choice" in
        1       ) reset && quotes_demo
                ;;
        2       ) reset && braces_demo
                ;;
        3       ) reset && variables_demo
                ;;
        4       ) reset && math_demo
                ;;
        [xX]    ) exit 0
                ;;
        [cC]    ) clear
                ;;
        *       ) echo "Please enter a valid option"
                ;;
    esac
done
}
# Run the program
mainMenu
