#!/bin/bash
  : '   # File  :         compressions.sh
        # Name  :         Greg Shrewsbury
        # Date  :         21Apr2020
        # Desc  :         Provide description of file compression types in liunx
        # Usage :         ./script.sh OR source script.sh'

# --- COLOR VARIABLES AND FUNCTIONS --- #
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White
    export NC='\e[0m'               # Text Reset
    export Black='\e[0;30m'         # Black
    export Red='\e[0;31m'           # Red
    export Green='\e[0;32m'         # Green
    export Yellow='\e[0;33m'        # Yellow
    export Blue='\e[0;34m'          # Blue
    export Purple='\e[0;35m'        # Purple
    export Cyan='\e[0;36m'          # Cyan
    export White='\e[0;37m'         # White

    function comm { echo -e "${BGreen}${1}${NC}"
    }
    function cli { echo -e "${Red}# ${1}${NC}"
    }
    function label { echo -e "${BBlue}${1}${NC}"
    }
    function output { echo -e "${NC}${1}\n"
    }

# --- Functions --- #
    reset
about_7z () {
    clear

    label "# --- *.7zip --- #\n"
    comm "# Save 3 files to a folder and confirm with an 'ls'"
    cli "export FOLDER='Test'; export ARCHIVE_NAME=Test.7z"
    cli "mkdir \$FOLDER"
    cli "for i in file_{1..3}; do echo \"Hello, World\" >> ./\$FOLDER/\${i}.txt; done"
    cli "ls -l ./\$FOLDER"

    output \
"total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"

    comm "# Use '7zip' to archive the folder."
    cli "7z a \$ARCHIVE_NAME \$FOLDER"

    output \
"Scanning the drive:
1 folder, 3 files, 0 bytes

Creating archive: temp.7z
Items to compress: 4
Files read from disk: 0

Archive size: 154 bytes (1 KiB)"

    comm "Confirm the archive was made"
    cli "ls -l Test*"

    output \
"drwxr-xr-x 2 root root 4096 Apr 27 18:16 Test
-rw-r--r-- 1 root root  154 Apr 27 18:23 Test.7z"

    comm "Extract the archive, and save the contents to a different directory"
    cli "NEW_FOLDER=Temp"
    cli "7z -o\${NEW_FOLDER} x Test.7z"
    cli "ls -l ./\$NEW_FOLDER"

    output \
"total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"
}

#################About gzip#########################

  reset
about_gzip () {
  clear

  label "# --- *.gzip --- #\n"
  comm "# Save 3 files to a folder and confirm with an 'ls'"
  cli "export FOLDER='test'; export ARCHIVE_NAME=test.gz"
  cli "mkdir \$FOLDER"
  cli "for i in file_{1..3}; do echo \"Hello, World\" >> ./\$FOLDER/\${i}.txt; done"
  cli "ls -l ./\$FOLDER"

    output \
"-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"

    comm "# Use 'gzip' to compress the file."
    cli "cd test"
    cli "gzip file_1.txt"

    comm "Confirm the zip file was made"
    cli "ls -l"

    output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt.gz
-rw-r--r-- 1 root root 44 Apr 28 10:09 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 10:09 file_3.txt"

    comm "#Or use 'gzip'on multiple files"
    cli "gzip file_2.txt file_3.txt"

    comm "Confirm the zip file was made"
    cli "ls -l"

    output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt.gz
-rw-r--r-- 1 root root 44 Apr 28 10:09 file_2.txt.gz
-rw-r--r-- 1 root root 13 Apr 28 10:09 file_3.txt.gz"

  comm "# Use 'gunzip' like g-unzip to decompress the file."
  cli "gunzip file_2.txt.gz file_3.txt.gz"

  comm "#Confirm zip was decompressed"
  cli "ls -l"

   output \
"-rw-r--r-- 1 root root 44 Apr 28 10:09 file_1.txt.gz
-rw-r--r-- 1 root root 44 Apr 28 10:10 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 10:10 file_3.txt"

}

#################About bzip2#########################

  reset
about_bzip2 () {
  clear

  label "# --- *.bzip2 --- #\n"
  comm "# Save 3 files to a folder and confirm with an 'ls'"
  cli "export FOLDER='example'; export ARCHIVE_NAME=example.bz"
  cli "mkdir \$FOLDER"
  cli "for i in file_{1..3}; do echo \"Hello, World\" >> ./\$FOLDER/\${i}.txt; done"
  cli "ls -l ./\$FOLDER"

  output \
"total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"

    comm "# Use 'bzip' to archive the folder."
    cli "cd example"
    cli "bzip2 file_1.txt"

    output \
  "total 0
  -rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt.bz2
  -rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt
  -rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt"

  comm "#Or use 'bzip2'on multiple files"
  cli "bzip2 file_2.txt file_3.txt"

  comm "#Confirm the bzip2 file was made"
  cli "ls -l"

  output \
"total 0
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_1.txt.bz2
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_2.txt.bz2
-rw-r--r-- 1 root root 0 Apr 27 18:16 file_3.txt.bz2"

  comm "#Use 'bzip2'to decompress a zipped file"
  cli "bzip2 -d file_1.txt.bz2 file_2.txt.bz2"

  comm "#Use extacted bzip2 as input for other file type."
  cli "bzip2 -d file_3.txt.bz2 | gzip file_3.txt | 7z a example1"

  comm "#Confirm files were changed."
  cli "ls -l"

  output \
"-rw-r--r-- 1 root root 195 Apr 28 18:03 example1.7z
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_1.txt
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_2.txt
-rw-r--r-- 1 root root  13 Apr 28 17:05 file_3.txt"

  comm "#Decrompress all"
  cli "p7zip -d example1.7z"

  comm "#Confirm all files returned"
  cli "ls -l"

  output \
"-rw-r--r-- 1 root root 13 Apr 28 17:05 file_1.txt
-rw-r--r-- 1 root root 13 Apr 28 17:05 file_2.txt
-rw-r--r-- 1 root root 13 Apr 28 17:05 file_3.txt"

}






















#about_tar () {
#reset
#echo -e "${BRed}	--- .tar ---"
#echo -e "${BGreen}	Or tape archives aka tarballs are used when compressing multiple files or directories. They can then also be compressed or zipped into a gzip file. This type of file will end in a .tar.gzor .tgz file extension. Gzip is most often used to compress text files, Tar archives, and web pages.
#	Common syntax is ${BPurple} <tar ${BRed}-c${BPurple}vf [new file name] [files you want to add to tar file]> to ${BRed}create ${BPurple}tar file. <tar ${BRed}-x${BPurple}vf [file name to decompress] to ${BRed}decompress ${BPurple}a tar."
#}

# --- Main --- #

mainMenu () {
reset
while :
do
        echo
        echo -e "${BCyan}Choose from the following options:"
        echo -e "${BGreen}# ---------------------------------- #${NC}"
        echo "   [1] *.7z"
        echo "   [2] *.gzip"
        echo "   [3] *.bzip2"
        echo "   [4] *.tar"
        echo
        echo -e "${BPurple}   [X] to Exit : [C] to Clear the Screen${NC}" && echo
        read -p "Choice: " choice
        echo
        case $choice in
            1) about_7z
                      ;;
            2) about_gzip
                      ;;
            3) about_bzip2
                      ;;
            4) about_tar
                      ;;
            [xX]) return 0
                      ;;
            [cC])  reset
                      ;;
            *) echo "Please enter a valid option"
                      ;;
      esac
      echo -e "\n\n\n"
done
}
# RUN THE PROGRAM
mainMenu
