#!/bin/bash
if : ; then
# File:         variables.sh
# Name:         Kevin Crotty
# Date:         31 Mar 2019
# Desc:         Variables in Bash
# Usage:       ./variables.sh 1337 CHEESE

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

: ' The two functions below colorize
    comments in green, and
    commands in red.'

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}

fi

reset

# Display Script Arguments
colorComment "# Arguments to 'variables.sh'"
echo "\$0 = '$0'"
echo "\$1 = '$1'"
echo "\$2 = '$2'"
echo "\$3 = '$3'"

# Variable Manipilation
colorComment "# String Manipulation: 1"
colorCommand "var=ying"
colorCommand "echo \$varyang\n"
colorCommand "echo \${var}yang"
echo -e "yingyang"

colorComment "# String Manipulation: 2"
colorCommand "str='Hello World'"
colorCommand "echo \${str:0:5}"
echo -e "Hello"
colorCommand "\necho \${str:6:5}"
echo -e "World"
colorCommand "\necho \${str/l/1}"
echo -e "He1lo World"
colorCommand "\necho \${str//l/1}"
echo -e "He11o Wor1d"
colorCommand "\necho \${str/Hello/Goodbye}"
echo -e "Goodbye World"

# Default Values
colorComment "# Setting Default Values"
colorCommand "var1=''"
colorCommand "echo \${var1:-\"A string\"}"
echo -e "A string"
colorCommand "\necho \$var1\n"

colorCommand "\nvar2=''"
colorCommand "echo \${var2:=\"A string\"}"
echo -e "A string"
colorCommand "\necho \$var2"
echo -e "A string"

colorCommand "\nvar3=''" ; var3=''
colorCommand "echo \${var3:?\"MY CUSTOM ERROR MESSAGE\"}" ;
echo -e "./variables.sh: line 69: var3: MY CUSTOM ERROR MESSAGE\n\n"
