#!/bin/bash

# -- COLOR VARIABLES AND FUNCTIONS
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White
    export BBlack='\e[1;30m'        # Black
    export Red='\e[0;31m'          # Red
    export Green='\e[0;32m'        # Green
    export Yellow='\e[0;33m'       # Yellow
    export Blue='\e[0;34m'         # Blue
    export Purple='\e[0;35m'       # Purple
    export Cyan='\e[0;36m'         # Cyan
    export White='\e[0;37m'        # White

    function comm { echo -e "${BGreen}${1}${NC}"
    }
    function cli { echo -e "${BRed}# ${1}${NC}"
    }
    function label { echo -e "${BBlue}${1}${NC}"
    }
    function output { echo -e "${NC}${1}\n"
    }

# --- Main --- #
reset

comm "# 1A - Generate some different encoded lines"
cli "echo 'First_Line' | base64 >> encoded.del"
cli "echo 'Second Line' | base32 >> encoded.del"
comm "# 1B - Needs extra newline to decode properly"
cli "echo 'The Third Line' | base58 >> encoded.del; echo >> encoded.del"

comm "\n# 2 - Show the encoded text"
cli "cat encoded.del"
output "Rmlyc3RfTGluZQo="
output "KNSWG33OMQQEY2LOMUFA===="
output "Y2osUScHqigKhYJR3ue"

comm "# 3 - For each line, attempt to decoded it, and save all output to decoded.del"
cli "while read line"
cli "do"
cli "    echo \"\$line\" | base64 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
cli "    echo \"\$line\" | base32 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
cli "    echo \"\$line\" | base58 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
cli "done < encoded.del"

#comm "# --  The individual tr commands are necessarry when using the delete option"
#output "${BGreen}#+ The ASCII octal ranges are split so that things like 'newline' characters are preserved${NC}"

#comm "# -- Delete all the byte patterns that match Octal 1-7 (Non-Rendering Symbols)"
#cli "LC_ALL=C tr -d '\1-\7' < decoded.del > tmp && mv tmp decoded.del"
#comm "# -- Delete all the byte patterns that match Octal 20-37 (Non-Rendering Symbols)"
#cli "LC_ALL=C tr -d '\20-\37' < decoded.del > tmp && mv tmp decoded.del"
#comm "# -- Delete all remaining bytes outside of the ASCII range"
#cli "LC_ALL=C tr -dc '\0-\177' < decoded.del > final.del"

comm "\n# 4 - Use strings command to get rid of unreadable characters"
cli "strings decoded.del"
output "First_Line"
output "Second Line"
output "cj,Q' ${Purple}<-- Ignore Garbage${NC}"
output "The Third Line"

comm "# 5 - Cleanup"
cli "rm *.del 2>/dev/null"
output "\n\n\n"
