#!/bin/bash

# File:         qemu-umount.sh
# Name:         Joseph Gerwing
# Date:         20200213
# Desc:         Automate unmounting fun.vdi filesystem
# Usage:        source qemu-umount.sh

# Color Variables
export BRED="\e[91m"
export BGREEN="\e[92m"
export BCYAN="\e[96m"
export NC="\e[0m"

# Function for highlighting comments
colorcomment () {
  echo -e "${BGREEN}$1${NC}"
}

clear

# Simulating load timer for unmounting commands
echo -ne "${BGREEN}Unmounting VDI filesystem" && sleep .9 && echo -ne "." && sleep .9 && echo -ne "." && sleep .9 && echo -e ".${NC}"

# Change directory to $HOME where fun.vdi is
echo -ne "${BGREEN}Changing directories to ${CYAN}\$HOME${BGREEN}..." && sleep .9 && echo -e "${BRED}cd${NC}"
cd

# Unmounts mount point hosting our VDI filesystem
echo -ne "${BGREEN}Unmounting ${BCYAN}fun${BGREEN}..." && sleep .9 && echo -e "${BRED}umount fun${NC}"
umount fun

# Verify fun is unmounted
echo -ne "${BGREEN}Verifying mount point is gone..." && sleep .9 && echo -e "${BRED}ls fun && df -h | egrep nbd0p1${NC}" sleep 2
ls fun && df -h | egrep nbd0p1

# Disconnects VDI associated device
echo -ne "${BGREEN}Disconnecting VDI associated device (nbd0p1)..." && sleep .9 && echo -e "${BRED}qemu-nbd -d /dev/nbd0${NC}"
qemu-nbd -d /dev/nbd0

# Verify VDI associated device (nbd0p1) is disconnected
echo -ne "${BGREEN}Verifying nbd0p1 is gone..." && sleep .9 && echo -e "${BRED}ls /dev/nbd0*"
ls /dev/nbd0*

# Fancy
colorcomment "LETS" && sleep .9
colorcomment "    BOOT" && sleep .9
colorcomment "        THE" && sleep .9
colorcomment "           VDI!" && sleep .9
